==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/block/base/FruitLeavesBlock.java <==
package cc.thonly.reverie_dreams.block.base;

import cc.thonly.reverie_dreams.block.BlockTypeGroup;
import com.mojang.serialization.MapCodec;
import lombok.Getter;
import net.minecraft.block.*;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1309;
import net.minecraft.class_1542;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1922;
import net.minecraft.class_1936;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2256;
import net.minecraft.class_2338;
import net.minecraft.class_2344;
import net.minecraft.class_2397;
import net.minecraft.class_2398;
import net.minecraft.class_2498;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2758;
import net.minecraft.class_3218;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3610;
import net.minecraft.class_3611;
import net.minecraft.class_3965;
import net.minecraft.class_4538;
import net.minecraft.class_5819;
import net.minecraft.class_5945;
import net.minecraft.class_9381;
import org.jetbrains.annotations.Nullable;

import java.util.ArrayList;
import java.util.List;

@Getter
public class FruitLeavesBlock extends class_2397 implements class_2256 {
    public static final MapCodec<FruitLeavesBlock> CODEC = FruitLeavesBlock.method_54094(FruitLeavesBlock::new);
    public static final List<FruitLeavesBlock> FRUIT_LEAVES_BLOCKS = new ArrayList<>();
    public static final int MAX_AGE = 3;
    public static final class_2758 AGE_PROPERTY = class_2758.method_11867("fruit_age", 0, MAX_AGE);
    private class_1792 output;
    private class_2248 emptyLeavesBlock;

    public FruitLeavesBlock(class_2251 settings) {
        super(0.01f, settings.method_22488());
        this.method_9590(
                this.method_9595()
                        .method_11664()
                        .method_11657(field_11199, 7)
                        .method_11657(AGE_PROPERTY, 0)
                        .method_11657(class_2397.field_38227, false)
        );
        BlockTypeGroup.FRUIT_LEAVES.add(this);
    }

    public FruitLeavesBlock(class_1792 output, class_2248 emptyLeavesBlock, class_2251 settings) {
        this(settings);
        this.emptyLeavesBlock = emptyLeavesBlock;
        this.output = output;
    }

    @Override
    protected class_1269 method_55766(class_2680 state, class_1937 world, class_2338 pos, class_1657 player, class_3965 hit) {
        class_1799 main = player.method_5998(class_1268.field_5808);
        class_1799 off = player.method_5998(class_1268.field_5810);
        boolean isGrowItem = main.method_7909() == class_1802.field_8324 || off.method_7909() == class_1802.field_8324;

        if (!world.method_8608() && world instanceof class_3218 serverWorld && isGrowItem) {
            return class_1269.field_5811;
        }
        if (isGrowItem) {
            class_5945.method_55636(world, pos, 3, class_2398.field_11211);
            return class_1269.field_5811;
        }

        if (!world.method_8608() && world instanceof class_3218 serverWorld) {
            Integer age = state.method_11654(AGE_PROPERTY);
            class_5819 random = world.method_8409();
            if (age >= MAX_AGE) {
                world.method_8396(null, pos, class_3417.field_17617, class_3419.field_15245, 1.0f, 0.8f + world.field_9229.method_43057() * 0.4f);
                class_1542 drop = new class_1542(serverWorld, pos.method_10263() + 0.5, pos.method_10264() + 0.5, pos.method_10260() + 0.5, new class_1799(this.output, random.method_39332(1, 3)));
                drop.method_6982(10);
                drop.method_18800(random.method_43056() ? random.method_43057() : -random.method_43057(), 0.2, random.method_43056() ? random.method_43057() : -random.method_43057());
                world.method_8649(drop);
                world.method_8501(pos, state.method_11657(AGE_PROPERTY, 1));
                return class_1269.field_52422;
            } else {
                return class_1269.field_5811;
            }
        }
        return class_1269.field_5812;
    }

    @Override
    protected class_2498 method_9573(class_2680 state) {
        return class_2498.field_11535;
    }

    @Override
    public boolean method_10311(class_1936 world, class_2338 pos, class_2680 state, class_3610 fluidState) {
        return false;
    }

    @Override
    public boolean method_10310(@Nullable class_1309 filler, class_1922 world, class_2338 pos, class_2680 state, class_3611 fluid) {
        return false;
    }

    @Override
    protected void method_9515(class_2689.class_2690<class_2248, class_2680> builder) {
        super.method_9515(builder);
        builder.method_11667(AGE_PROPERTY);
    }

    @Override
    public MapCodec<? extends class_2397> method_53969() {
        return field_46280;
    }

    @Override
    protected void method_67234(class_1937 world, class_2338 pos, class_5819 random) {
        class_9381 entityEffectParticleEffect = class_9381.method_58256(class_2398.field_55880, world.method_67233(pos));
        class_5945.method_49099(world, pos, random, entityEffectParticleEffect);
    }

    @Override
    public void method_9514(class_2680 state, class_3218 world, class_2338 pos, class_5819 random) {
        float f;
        int i;
        if (world.method_22335(pos, 0) >= 9 && (i = this.getAge(state)) < MAX_AGE && random.method_43048((int) (25.0f / (f = getAvailableMoisture(this, world, pos))) + 1) == 0) {
            world.method_8652(pos, this.withAge(i + 1), class_2248.field_31028);
        }
    }

    public class_2680 withAge(int age) {
        return this.method_9564().method_11657(AGE_PROPERTY, age);
    }

    public int getAge(class_2680 state) {
        return state.method_11654(AGE_PROPERTY);
    }

    @Override
    public boolean method_9651(class_4538 world, class_2338 pos, class_2680 state) {
        return true;
    }

    @Override
    protected boolean method_9542(class_2680 state) {
        return true;
    }

    @Override
    public boolean method_9650(class_1937 world, class_5819 random, class_2338 pos, class_2680 state) {
        return state.method_11654(AGE_PROPERTY) < MAX_AGE;
    }

    @Override
    public void method_9652(class_3218 world, class_5819 random, class_2338 pos, class_2680 state) {
        float f;
        int age = state.method_11654(AGE_PROPERTY);
//        System.out.println(age);
        if (age < MAX_AGE) {
            world.method_8652(pos, state.method_11657(AGE_PROPERTY, Math.min(age + 1, MAX_AGE)), class_2248.field_31022);
        }
    }

    protected static float getAvailableMoisture(class_2248 block, class_1922 world, class_2338 pos) {
        boolean bl2;
        float f = 1.0f;
        class_2338 blockPos = pos.method_10074();
        for (int i = -1; i <= 1; ++i) {
            for (int j = -1; j <= 1; ++j) {
                float g = 0.0f;
                class_2680 blockState = world.method_8320(blockPos.method_10069(i, 0, j));
                if (blockState.method_27852(class_2246.field_10362)) {
                    g = 1.0f;
                    if (blockState.method_11654(class_2344.field_11009) > 0) {
                        g = 3.0f;
                    }
                }
                if (i != 0 || j != 0) {
                    g /= 4.0f;
                }
                f += g;
            }
        }
        class_2338 blockPos2 = pos.method_10095();
        class_2338 blockPos3 = pos.method_10072();
        class_2338 blockPos4 = pos.method_10067();
        class_2338 blockPos5 = pos.method_10078();
        boolean bl = world.method_8320(blockPos4).method_27852(block) || world.method_8320(blockPos5).method_27852(block);
        boolean bl3 = bl2 = world.method_8320(blockPos2).method_27852(block) || world.method_8320(blockPos3).method_27852(block);
        if (bl && bl2) {
            f /= 2.0f;
        } else {
            boolean bl32;
            boolean bl4 = bl32 = world.method_8320(blockPos4.method_10095()).method_27852(block) || world.method_8320(blockPos5.method_10095()).method_27852(block) || world.method_8320(blockPos5.method_10072()).method_27852(block) || world.method_8320(blockPos4.method_10072()).method_27852(block);
            if (bl32) {
                f /= 2.0f;
            }
        }
        return f;
    }


}

==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/block/base/FruitLeavesBlock.java <==
package cc.thonly.reverie_dreams.block.base;

import cc.thonly.reverie_dreams.block.BlockTypeGroup;
import com.mojang.serialization.MapCodec;
import lombok.Getter;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1309;
import net.minecraft.class_1542;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1922;
import net.minecraft.class_1936;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2256;
import net.minecraft.class_2338;
import net.minecraft.class_2344;
import net.minecraft.class_2397;
import net.minecraft.class_2398;
import net.minecraft.class_2498;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2758;
import net.minecraft.class_3218;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3610;
import net.minecraft.class_3611;
import net.minecraft.class_3965;
import net.minecraft.class_4538;
import net.minecraft.class_5819;
import net.minecraft.class_5945;
import net.minecraft.class_9381;
import org.jetbrains.annotations.Nullable;

import java.util.ArrayList;
import java.util.List;

@Getter
public class FruitLeavesBlock extends class_2397 implements class_2256 {
    public static final MapCodec<FruitLeavesBlock> CODEC = FruitLeavesBlock.method_54094(FruitLeavesBlock::new);
    public static final List<FruitLeavesBlock> FRUIT_LEAVES_BLOCKS = new ArrayList<>();
    public static final int MAX_AGE = 3;
    public static final class_2758 AGE_PROPERTY = class_2758.method_11867("fruit_age", 0, MAX_AGE);
    private class_1792 output;
    private class_2248 emptyLeavesBlock;

    public FruitLeavesBlock(class_2251 settings) {
        super(0.01f, settings.method_22488());
        this.method_9590(
                this.method_9595()
                        .method_11664()
                        .method_11657(field_11199, 7)
                        .method_11657(AGE_PROPERTY, MAX_AGE)
                        .method_11657(class_2397.field_38227, false)
        );
        BlockTypeGroup.FRUIT_LEAVES.add(this);
    }

    public FruitLeavesBlock(class_1792 output, class_2248 emptyLeavesBlock, class_2251 settings) {
        this(settings);
        this.emptyLeavesBlock = emptyLeavesBlock;
        this.output = output;
    }

    @Override
    protected class_1269 method_55766(class_2680 state, class_1937 world, class_2338 pos, class_1657 player, class_3965 hit) {
        class_1799 main = player.method_5998(class_1268.field_5808);
        class_1799 off = player.method_5998(class_1268.field_5810);
        boolean isGrowItem = main.method_7909() == class_1802.field_8324 || off.method_7909() == class_1802.field_8324;

        if (!world.method_8608() && world instanceof class_3218 serverWorld && isGrowItem) {
            return class_1269.field_5811;
        }
        if (isGrowItem) {
            class_5945.method_55636(world, pos, 3, class_2398.field_11211);
            return class_1269.field_5811;
        }

        if (!world.method_8608() && world instanceof class_3218 serverWorld) {
            Integer age = state.method_11654(AGE_PROPERTY);
            class_5819 random = world.method_8409();
            if (age >= MAX_AGE) {
                world.method_8396(null, pos, class_3417.field_17617, class_3419.field_15245, 1.0f, 0.8f + world.field_9229.method_43057() * 0.4f);
                class_1542 drop = new class_1542(serverWorld, pos.method_10263() + 0.5, pos.method_10264() + 0.5, pos.method_10260() + 0.5, new class_1799(this.output, random.method_39332(1, 3)));
                drop.method_6982(10);
                drop.method_18800(random.method_43056() ? random.method_43057() : -random.method_43057(), 0.2, random.method_43056() ? random.method_43057() : -random.method_43057());
                world.method_8649(drop);
                world.method_8501(pos, state.method_11657(AGE_PROPERTY, 1));
                return class_1269.field_52422;
            } else {
                return class_1269.field_5811;
            }
        }
        return class_1269.field_5812;
    }

    @Override
    protected class_2498 method_9573(class_2680 state) {
        return class_2498.field_11535;
    }

    @Override
    public boolean method_10311(class_1936 world, class_2338 pos, class_2680 state, class_3610 fluidState) {
        return false;
    }

    @Override
    public boolean method_10310(@Nullable class_1309 filler, class_1922 world, class_2338 pos, class_2680 state, class_3611 fluid) {
        return false;
    }

    @Override
    protected void method_9515(class_2689.class_2690<class_2248, class_2680> builder) {
        super.method_9515(builder);
        builder.method_11667(AGE_PROPERTY);
    }

    @Override
    public MapCodec<? extends class_2397> method_53969() {
        return field_46280;
    }

    @Override
    protected void method_67234(class_1937 world, class_2338 pos, class_5819 random) {
        class_9381 entityEffectParticleEffect = class_9381.method_58256(class_2398.field_55880, world.method_67233(pos));
        class_5945.method_49099(world, pos, random, entityEffectParticleEffect);
    }

    @Override
    public void method_9514(class_2680 state, class_3218 world, class_2338 pos, class_5819 random) {
        float f;
        int i;
        if (world.method_22335(pos, 0) >= 9 && (i = this.getAge(state)) < MAX_AGE && random.method_43048((int) (25.0f / (f = getAvailableMoisture(this, world, pos))) + 1) == 0) {
            world.method_8652(pos, this.withAge(i + 1), class_2248.field_31028);
        }
    }

    public class_2680 withAge(int age) {
        return this.method_9564().method_11657(AGE_PROPERTY, age);
    }

    public int getAge(class_2680 state) {
        return state.method_11654(AGE_PROPERTY);
    }

    @Override
    public boolean method_9651(class_4538 world, class_2338 pos, class_2680 state) {
        return true;
    }

    @Override
    protected boolean method_9542(class_2680 state) {
        return true;
    }

    @Override
    public boolean method_9650(class_1937 world, class_5819 random, class_2338 pos, class_2680 state) {
        return state.method_11654(AGE_PROPERTY) < MAX_AGE;
    }

    @Override
    public void method_9652(class_3218 world, class_5819 random, class_2338 pos, class_2680 state) {
        float f;
        int age = state.method_11654(AGE_PROPERTY);
//        System.out.println(age);
        if (age < MAX_AGE) {
            world.method_8652(pos, state.method_11657(AGE_PROPERTY, Math.min(age + 1, MAX_AGE)), class_2248.field_31022);
        }
    }

    protected static float getAvailableMoisture(class_2248 block, class_1922 world, class_2338 pos) {
        boolean bl2;
        float f = 1.0f;
        class_2338 blockPos = pos.method_10074();
        for (int i = -1; i <= 1; ++i) {
            for (int j = -1; j <= 1; ++j) {
                float g = 0.0f;
                class_2680 blockState = world.method_8320(blockPos.method_10069(i, 0, j));
                if (blockState.method_27852(class_2246.field_10362)) {
                    g = 1.0f;
                    if (blockState.method_11654(class_2344.field_11009) > 0) {
                        g = 3.0f;
                    }
                }
                if (i != 0 || j != 0) {
                    g /= 4.0f;
                }
                f += g;
            }
        }
        class_2338 blockPos2 = pos.method_10095();
        class_2338 blockPos3 = pos.method_10072();
        class_2338 blockPos4 = pos.method_10067();
        class_2338 blockPos5 = pos.method_10078();
        boolean bl = world.method_8320(blockPos4).method_27852(block) || world.method_8320(blockPos5).method_27852(block);
        boolean bl3 = bl2 = world.method_8320(blockPos2).method_27852(block) || world.method_8320(blockPos3).method_27852(block);
        if (bl && bl2) {
            f /= 2.0f;
        } else {
            boolean bl32;
            boolean bl4 = bl32 = world.method_8320(blockPos4.method_10095()).method_27852(block) || world.method_8320(blockPos5.method_10095()).method_27852(block) || world.method_8320(blockPos5.method_10072()).method_27852(block) || world.method_8320(blockPos4.method_10072()).method_27852(block);
            if (bl32) {
                f /= 2.0f;
            }
        }
        return f;
    }


}
